@@ -82,9 +82,13 @@ def collect_reqs() -> List[str]:
 
 
 def collect_bootstrap_reqs() -> List[str]:
-    # pylint: disable=import-outside-toplevel,no-name-in-module,import-error,no-member
-    import config.bootstrap
-    return config.bootstrap.requires
+    try:
+        mod = importlib.import_module("config.bootstrap")
+        if hasattr(mod, "requires"):
+            return getattr(mod, "requires")
+    except ModuleNotFoundError:
+        pass
+    return []
 
 
 def get_install_args():
